AdminLTE 3 | General Form Elements

# General Form

### Quick Example

Email address
Password
File input
Choose file
Upload
Check me out

### Different Styles

#### Input

Bottom Border only `.form-control-border`
Bottom Border only 2px Border `.form-control-border.border-width-2`
Flat `.rounded-0`

#### Custom Select

Bottom Border only `.form-control-border`
Bottom Border only `.form-control-border.border-width-2`
Flat `.rounded-0`

### Input Addon

@
.00
$
.00

#### With icons

##### With checkbox and radio inputs

##### With buttons

Large: `.input-group.input-group-lg`

Normal

Small `.input-group.input-group-sm`

### Horizontal Form

Email
Password
Remember me

### Different Height

### Different Width

### General Elements

Text
Text Disabled
Textarea
Textarea Disabled
Input with success
Input with warning
Input with error
Checkbox
Checkbox checked
Checkbox disabled
Radio
Radio checked
Radio disabled
Select
Select Disabled
Select Multiple
Select Multiple Disabled

### Custom Elements

Custom Checkbox
Custom Checkbox checked
Custom Checkbox disabled
Custom Checkbox with custom color
Custom Checkbox with custom color outline
Custom Radio
Custom Radio checked
Custom Radio disabled
Custom Radio with custom color
Custom Radio with custom color outline
Custom Select
Custom Select Disabled
Custom Select Multiple
Custom Select Multiple Disabled
Toggle this custom switch element
Toggle this custom switch element with custom colors danger/success
Disabled custom switch element
Custom range
Custom range (custom-range-danger)
Custom range (custom-range-teal)
Choose file